@@ -839,6 +839,9 @@ class BaseBenchmark(ABC):
                         # Set transformers logging back to error
                         tf_logging.set_verbosity_error()
 
+                        # Remove trainer logging
+                        trainer.log = lambda _: None
+
                         # Remove the callback which prints the metrics after
                         # each evaluation
                         if not self.verbose:
